Contributors
------------

- [Jim Ramsay](mailto:i.am@jimramsay.com) - Author
- [Christoph](mailto:soffioalcuore@posteo.net) - Testing and suggestions
- [Pete Merges](mailto:pdmerges@gmail.com) - Notepad-8FX support and testing
- [Viktor Mastoridis](mailto:viktor.mastoridis@gmail.com) - Notepad-5 support and testing
- [Hans Ulrich Niedermann](mailto:hun@n-dimensional.de) - System integration

Artwork
-------

- Icon by [Flat Icons](https://www.flaticon.com/authors/flat-icons) from http://www.flaticon.com/
